==> custom_pages-v1.12.8.zip: custom_pages/messages/tr/base.php <==
<?php

return [
    'Add' => 'Ekle',
    'Advanced' => 'Gelişmiş',
    'Always' => 'Herzaman',
    'Back' => 'Geri',
    'Back to dashboard' => 'Gösterge paneline geri dön',
    'Back to overview' => 'Geri dön',
    'Back to space' => 'Mekanlara geri dön',
    'Category' => 'Kategori',
    'Configuration' => 'Konfigürasyon',
    'Content' => 'İçerik',
    'Create' => 'Oluştur',
    'Custom' => 'Gelenek',
    'Custom Pages' => 'Özel Sayfalar',
    'Dashboard' => 'Panel',
    'Default' => 'Varsayılan',
    'Delete' => 'Sil',
    'Edit' => 'Düzenle',
    'File' => 'Dosya',
    'General' => 'Genel',
    'ID' => 'ID',
    'Insert' => 'Ekle',
    'Link' => 'Bağlantı',
    'MarkDown' => 'Daralt',
    'Navigation' => 'Navigasyon',
    'Overview' => 'Genel Bakış',
    'Public' => 'Herkes',
    'Reset' => 'Sıfırla',
    'Settings' => 'Ayarlar',
    'Sort Order' => 'Sıralama',
    'Space' => 'Mekan',
    'Spaces' => 'Mekanlar',
    'Stream' => 'Yayın',
    'Submit' => 'Gönder',
    'Title' => 'Başlık',
    'Top Navigation' => 'En Navigasyon',
    'Topics' => 'Konular',
    'Type' => 'Tip',
    'User Account Menu (Settings)' => 'Kullanıcı Hesap Menüsü (Ayarlar)',
    'Visibility' => 'Görünüm',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'PHP tabanlı sayfaları ile dosya sisteminde görünüm dosyaları vasıtasıyla özel sayfalar oluşturabilirsiniz. Daha fazla bilgi için lütfen modül yapılandırmasını kontrol edin.',
    'Without adding to navigation (Direct link)' => 'Navigasyon eklemeden (Doğrudan bağlantı)',
    '<strong>Add</strong> {templateName} item' => '',
    '<strong>Custom</strong> Pages' => '',
    '<strong>Edit</strong> snippet' => '',
    'Add a file icon before the title' => '',
    'Additional IFrame Attributes' => '',
    'Adds plain HTML content to your site.' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => '',
    'Allows you to add content in MarkDown syntax.' => '',
    'Alternate text' => '',
    'Always make a backup of your view files outside of your production environment!' => '',
    'An empty allowed template selection will allow all container templates for this container.' => '',
    'Authors' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Css Class' => '',
    'Custom pages' => '',
    'Default Content' => '',
    'Deleted.' => '',
    'Edit Page' => '',
    'Empty' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Html' => '',
    'Icon' => '',
    'Iframe' => '',
    'Import' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid type selection' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'On this page you can configure general settings of your custom pages.' => '',
    'PHP' => '',
    'Page' => '',
    'Page Content' => '',
    'Pages' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Show additional file information (size)' => '',
    'Snippet' => '',
    'Snippets' => '',
    'Source' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Style' => '',
    'Style Class' => '',
    'Target Url' => '',
    'Template' => '',
    'Template Layout' => '',
    'Templates' => '',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => '',
    'This container does not allow any further items!' => '',
    'Upload image' => '',
    'Usage' => '',
    'Will embed the result of a given url as an iframe element.' => '',
    'Will redirect requests to a given (relative or absolute) url.' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/tr/base.php <==
<?php

return [
    'Add' => 'Ekle',
    'Advanced' => 'Gelişmiş',
    'Always' => 'Herzaman',
    'Back' => 'Geri',
    'Back to dashboard' => 'Gösterge paneline geri dön',
    'Back to overview' => 'Geri dön',
    'Back to space' => 'Mekanlara geri dön',
    'Category' => 'Kategori',
    'Configuration' => 'Konfigürasyon',
    'Content' => 'İçerik',
    'Create' => 'Oluştur',
    'Custom' => 'Gelenek',
    'Custom Pages' => 'Özel Sayfalar',
    'Dashboard' => 'Panel',
    'Default' => 'Varsayılan',
    'Delete' => 'Sil',
    'Edit' => 'Düzenle',
    'File' => 'Dosya',
    'General' => 'Genel',
    'ID' => 'ID',
    'Insert' => 'Ekle',
    'Link' => 'Bağlantı',
    'MarkDown' => 'Daralt',
    'Navigation' => 'Navigasyon',
    'Overview' => 'Genel Bakış',
    'Public' => 'Herkes',
    'Reset' => 'Sıfırla',
    'Settings' => 'Ayarlar',
    'Sort Order' => 'Sıralama',
    'Space' => 'Mekan',
    'Spaces' => 'Mekanlar',
    'Stream' => 'Yayın',
    'Submit' => 'Gönder',
    'Title' => 'Başlık',
    'Top Navigation' => 'En Navigasyon',
    'Topics' => 'Konular',
    'Type' => 'Tip',
    'User Account Menu (Settings)' => 'Kullanıcı Hesap Menüsü (Ayarlar)',
    'Visibility' => 'Görünüm',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'PHP tabanlı sayfaları ile dosya sisteminde görünüm dosyaları vasıtasıyla özel sayfalar oluşturabilirsiniz. Daha fazla bilgi için lütfen modül yapılandırmasını kontrol edin.',
    'Without adding to navigation (Direct link)' => 'Navigasyon eklemeden (Doğrudan bağlantı)',
    '<strong>Add</strong> {templateName} item' => '',
    '<strong>Custom</strong> Pages' => '',
    '<strong>Edit</strong> snippet' => '',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Add a file icon before the title' => '',
    'Additional IFrame Attributes' => '',
    'Adds plain HTML content to your site.' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => '',
    'Allows you to add content in MarkDown syntax.' => '',
    'Alternate text' => '',
    'Always make a backup of your view files outside of your production environment!' => '',
    'An empty allowed template selection will allow all container templates for this container.' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Css Class' => '',
    'Custom pages' => '',
    'Default Content' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Edit Page' => '',
    'Empty' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Html' => '',
    'Icon' => '',
    'Iframe' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid type selection' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'On this page you can configure general settings of your custom pages.' => '',
    'PHP' => '',
    'Page' => '',
    'Page Content' => '',
    'Pages' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Show additional file information (size)' => '',
    'Snippet' => '',
    'Snippets' => '',
    'Sorting' => '',
    'Source' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Style' => '',
    'Style Class' => '',
    'Target Url' => '',
    'Template' => '',
    'Template Layout' => '',
    'Templates' => '',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => '',
    'This container does not allow any further items!' => '',
    'Upload image' => '',
    'Usage' => '',
    'Will embed the result of a given url as an iframe element.' => '',
    'Will redirect requests to a given (relative or absolute) url.' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];
